# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import sequencer_connect_service_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2
from . import service_agreement_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2
from ....protocol.v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/domain/api/v0/sequencer_connect_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SequencerConnectServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Handshake = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/Handshake',
                request_serializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.Handshake.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.Handshake.Response.FromString,
                _registered_method=True)
        self.GetDomainId = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/GetDomainId',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainId.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainId.Response.FromString,
                _registered_method=True)
        self.GetDomainParameters = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/GetDomainParameters',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainParameters.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainParameters.Response.FromString,
                _registered_method=True)
        self.VerifyActive = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/VerifyActive',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.VerifyActive.Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.VerifyActive.Response.FromString,
                _registered_method=True)
        self.GetServiceAgreement = channel.unary_unary(
                '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/GetServiceAgreement',
                request_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2.GetServiceAgreementRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2.GetServiceAgreementResponse.FromString,
                _registered_method=True)


class SequencerConnectServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Handshake(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomainId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomainParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyActive(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceAgreement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SequencerConnectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Handshake': grpc.unary_unary_rpc_method_handler(
                    servicer.Handshake,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.Handshake.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.Handshake.Response.SerializeToString,
            ),
            'GetDomainId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomainId,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainId.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainId.Response.SerializeToString,
            ),
            'GetDomainParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomainParameters,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainParameters.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainParameters.Response.SerializeToString,
            ),
            'VerifyActive': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyActive,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.VerifyActive.Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.VerifyActive.Response.SerializeToString,
            ),
            'GetServiceAgreement': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceAgreement,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2.GetServiceAgreementRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2.GetServiceAgreementResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.domain.api.v0.SequencerConnectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.domain.api.v0.SequencerConnectService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SequencerConnectService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Handshake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/Handshake',
            com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.Handshake.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2.Handshake.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDomainId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/GetDomainId',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainId.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainId.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDomainParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/GetDomainParameters',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainParameters.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.GetDomainParameters.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VerifyActive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/VerifyActive',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.VerifyActive.Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connect__service__pb2.SequencerConnect.VerifyActive.Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetServiceAgreement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.domain.api.v0.SequencerConnectService/GetServiceAgreement',
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2.GetServiceAgreementRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_service__agreement__pb2.GetServiceAgreementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/acs_commitments.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v0/acs_commitments.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9com/digitalasset/canton/protocol/v0/acs_commitments.proto\x12#com.digitalasset.canton.protocol.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb0\x02\n\rAcsCommitment\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12/\n\x13sending_participant\x18\x02 \x01(\tR\x12sendingParticipant\x12/\n\x13\x63ounter_participant\x18\x03 \x01(\tR\x12\x63ounterParticipant\x12\x41\n\x0e\x66rom_exclusive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rfromExclusive\x12=\n\x0cto_inclusive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btoInclusive\x12\x1e\n\ncommitment\x18\x06 \x01(\x0cR\ncommitmentBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.acs_commitments_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_ACSCOMMITMENT']._serialized_start=132
  _globals['_ACSCOMMITMENT']._serialized_end=436
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import object_meta_pb2 as _object_meta_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetParticipantIdRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetParticipantIdResponse(_message.Message):
    __slots__ = ("participant_id",)
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    participant_id: str
    def __init__(self, participant_id: _Optional[str] = ...) -> None: ...

class GetPartiesRequest(_message.Message):
    __slots__ = ("parties", "identity_provider_id")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    identity_provider_id: str
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class GetPartiesResponse(_message.Message):
    __slots__ = ("party_details",)
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    party_details: _containers.RepeatedCompositeFieldContainer[PartyDetails]
    def __init__(self, party_details: _Optional[_Iterable[_Union[PartyDetails, _Mapping]]] = ...) -> None: ...

class ListKnownPartiesRequest(_message.Message):
    __slots__ = ("page_token", "page_size", "identity_provider_id")
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    page_token: str
    page_size: int
    identity_provider_id: str
    def __init__(self, page_token: _Optional[str] = ..., page_size: _Optional[int] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class ListKnownPartiesResponse(_message.Message):
    __slots__ = ("party_details", "next_page_token")
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    party_details: _containers.RepeatedCompositeFieldContainer[PartyDetails]
    next_page_token: str
    def __init__(self, party_details: _Optional[_Iterable[_Union[PartyDetails, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class AllocatePartyRequest(_message.Message):
    __slots__ = ("party_id_hint", "display_name", "local_metadata", "identity_provider_id")
    PARTY_ID_HINT_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    LOCAL_METADATA_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    party_id_hint: str
    display_name: str
    local_metadata: _object_meta_pb2.ObjectMeta
    identity_provider_id: str
    def __init__(self, party_id_hint: _Optional[str] = ..., display_name: _Optional[str] = ..., local_metadata: _Optional[_Union[_object_meta_pb2.ObjectMeta, _Mapping]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class AllocatePartyResponse(_message.Message):
    __slots__ = ("party_details",)
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    party_details: PartyDetails
    def __init__(self, party_details: _Optional[_Union[PartyDetails, _Mapping]] = ...) -> None: ...

class UpdatePartyDetailsRequest(_message.Message):
    __slots__ = ("party_details", "update_mask")
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    party_details: PartyDetails
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, party_details: _Optional[_Union[PartyDetails, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdatePartyDetailsResponse(_message.Message):
    __slots__ = ("party_details",)
    PARTY_DETAILS_FIELD_NUMBER: _ClassVar[int]
    party_details: PartyDetails
    def __init__(self, party_details: _Optional[_Union[PartyDetails, _Mapping]] = ...) -> None: ...

class PartyDetails(_message.Message):
    __slots__ = ("party", "display_name", "is_local", "local_metadata", "identity_provider_id")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    IS_LOCAL_FIELD_NUMBER: _ClassVar[int]
    LOCAL_METADATA_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    party: str
    display_name: str
    is_local: bool
    local_metadata: _object_meta_pb2.ObjectMeta
    identity_provider_id: str
    def __init__(self, party: _Optional[str] = ..., display_name: _Optional[str] = ..., is_local: bool = ..., local_metadata: _Optional[_Union[_object_meta_pb2.ObjectMeta, _Mapping]] = ..., identity_provider_id: _Optional[str] = ...) -> None: ...

class UpdatePartyIdentityProviderRequest(_message.Message):
    __slots__ = ("party", "source_identity_provider_id", "target_identity_provider_id")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    SOURCE_IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    party: str
    source_identity_provider_id: str
    target_identity_provider_id: str
    def __init__(self, party: _Optional[str] = ..., source_identity_provider_id: _Optional[str] = ..., target_identity_provider_id: _Optional[str] = ...) -> None: ...

class UpdatePartyIdentityProviderResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/crypto/v30/crypto.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/crypto/v30/crypto.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/com/digitalasset/canton/crypto/v30/crypto.proto\x12\"com.digitalasset.canton.crypto.v30\"k\n\x04Hmac\x12O\n\talgorithm\x18\x01 \x01(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HmacAlgorithmR\talgorithm\x12\x12\n\x04hmac\x18\x02 \x01(\x0cR\x04hmac\"p\n\x04Salt\x12G\n\x04hmac\x18\x01 \x01(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HmacAlgorithmH\x00R\x04hmac\x12\x12\n\x04salt\x18\x02 \x01(\x0cR\x04saltB\x0b\n\talgorithm\"\x93\x01\n\tSignature\x12K\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.SignatureFormatR\x06\x66ormat\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12\x1b\n\tsigned_by\x18\x03 \x01(\tR\x08signedBy\"\xe7\x01\n\tPublicKey\x12\x64\n\x12signing_public_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyH\x00R\x10signingPublicKey\x12m\n\x15\x65ncryption_public_key\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyH\x00R\x13\x65ncryptionPublicKeyB\x05\n\x03key\"u\n\x11PublicKeyWithName\x12L\n\npublic_key\x18\x01 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.PublicKeyR\tpublicKey\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\xee\x01\n\nPrivateKey\x12g\n\x13signing_private_key\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.SigningPrivateKeyH\x00R\x11signingPrivateKey\x12p\n\x16\x65ncryption_private_key\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.crypto.v30.EncryptionPrivateKeyH\x00R\x14\x65ncryptionPrivateKeyB\x05\n\x03key\"\xd2\x01\n\x10SigningPublicKey\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1d\n\npublic_key\x18\x03 \x01(\x0cR\tpublicKey\x12L\n\x06scheme\x18\x04 \x01(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\x06schemeJ\x04\x08\x01\x10\x02\"\xdf\x01\n\x11SigningPrivateKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1f\n\x0bprivate_key\x18\x03 \x01(\x0cR\nprivateKey\x12L\n\x06scheme\x18\x04 \x01(\x0e\x32\x34.com.digitalasset.canton.crypto.v30.SigningKeySchemeR\x06scheme\"\xbd\x01\n\x0eSigningKeyPair\x12S\n\npublic_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\tpublicKey\x12V\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.SigningPrivateKeyR\nprivateKey\"\xae\x02\n\x13\x45ncryptionPublicKey\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1d\n\npublic_key\x18\x03 \x01(\x0cR\tpublicKey\x12S\n\x06scheme\x18\x04 \x01(\x0e\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionKeySchemeB\x02\x18\x01R\x06scheme\x12P\n\x08key_spec\x18\x05 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x07keySpecJ\x04\x08\x01\x10\x02\"\xbb\x02\n\x14\x45ncryptionPrivateKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12K\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x1f\n\x0bprivate_key\x18\x03 \x01(\x0cR\nprivateKey\x12S\n\x06scheme\x18\x04 \x01(\x0e\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionKeySchemeB\x02\x18\x01R\x06scheme\x12P\n\x08key_spec\x18\x05 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x07keySpec\"\xc6\x01\n\x11\x45ncryptionKeyPair\x12V\n\npublic_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyR\tpublicKey\x12Y\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.crypto.v30.EncryptionPrivateKeyR\nprivateKey\"\xc1\x01\n\x17RequiredEncryptionSpecs\x12[\n\nalgorithms\x18\x01 \x03(\x0e\x32;.com.digitalasset.canton.crypto.v30.EncryptionAlgorithmSpecR\nalgorithms\x12I\n\x04keys\x18\x02 \x03(\x0e\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeySpecR\x04keys\"\xe0\x01\n\rCryptoKeyPair\x12^\n\x10signing_key_pair\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.crypto.v30.SigningKeyPairH\x00R\x0esigningKeyPair\x12g\n\x13\x65ncryption_key_pair\x18\x02 \x01(\x0b\x32\x35.com.digitalasset.canton.crypto.v30.EncryptionKeyPairH\x00R\x11\x65ncryptionKeyPairB\x06\n\x04pair\"\xbd\x01\n\x0cSymmetricKey\x12K\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x06\x66ormat\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12N\n\x06scheme\x18\x03 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x06scheme\"\x8a\x02\n\x16PasswordBasedEncrypted\x12\x1e\n\nciphertext\x18\x01 \x01(\x0cR\nciphertext\x12h\n\x14symmetric_key_scheme\x18\x02 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x12symmetricKeyScheme\x12R\n\x0cpbkdf_scheme\x18\x03 \x01(\x0e\x32/.com.digitalasset.canton.crypto.v30.PbkdfSchemeR\x0bpbkdfScheme\x12\x12\n\x04salt\x18\x04 \x01(\x0cR\x04salt*J\n\rHashAlgorithm\x12\x1e\n\x1aHASH_ALGORITHM_UNSPECIFIED\x10\x00\x12\x19\n\x15HASH_ALGORITHM_SHA256\x10\x01*O\n\rHmacAlgorithm\x12\x1e\n\x1aHMAC_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1e\n\x1aHMAC_ALGORITHM_HMAC_SHA256\x10\x01*M\n\x0fSignatureFormat\x12 \n\x1cSIGNATURE_FORMAT_UNSPECIFIED\x10\x00\x12\x18\n\x14SIGNATURE_FORMAT_RAW\x10\x01*{\n\x11\x45ncryptionKeySpec\x12#\n\x1f\x45NCRYPTION_KEY_SPEC_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45NCRYPTION_KEY_SPEC_EC_P256\x10\x01\x12 \n\x1c\x45NCRYPTION_KEY_SPEC_RSA_2048\x10\x03*^\n\nKeyPurpose\x12\x1b\n\x17KEY_PURPOSE_UNSPECIFIED\x10\x00\x12\x17\n\x13KEY_PURPOSE_SIGNING\x10\x01\x12\x1a\n\x16KEY_PURPOSE_ENCRYPTION\x10\x02*\x9e\x01\n\x10SigningKeyScheme\x12\"\n\x1eSIGNING_KEY_SCHEME_UNSPECIFIED\x10\x00\x12\x1e\n\x1aSIGNING_KEY_SCHEME_ED25519\x10\x01\x12\"\n\x1eSIGNING_KEY_SCHEME_EC_DSA_P256\x10\x02\x12\"\n\x1eSIGNING_KEY_SCHEME_EC_DSA_P384\x10\x03*\xf3\x01\n\x17\x45ncryptionAlgorithmSpec\x12)\n%ENCRYPTION_ALGORITHM_SPEC_UNSPECIFIED\x10\x00\x12>\n:ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128GCM\x10\x01\x12>\n:ENCRYPTION_ALGORITHM_SPEC_ECIES_HKDF_HMAC_SHA256_AES128CBC\x10\x02\x12-\n)ENCRYPTION_ALGORITHM_SPEC_RSA_OAEP_SHA256\x10\x03*\xe8\x01\n\x13\x45ncryptionKeyScheme\x12%\n!ENCRYPTION_KEY_SCHEME_UNSPECIFIED\x10\x00\x12?\n;ENCRYPTION_KEY_SCHEME_ECIES_P256_HKDF_HMAC_SHA256_AES128GCM\x10\x01\x12:\n6ENCRYPTION_KEY_SCHEME_ECIES_P256_HMAC_SHA256A_ES128CBC\x10\x02\x12-\n)ENCRYPTION_KEY_SCHEME_RSA2048_OAEP_SHA256\x10\x03*^\n\x12SymmetricKeyScheme\x12$\n SYMMETRIC_KEY_SCHEME_UNSPECIFIED\x10\x00\x12\"\n\x1eSYMMETRIC_KEY_SCHEME_AES128GCM\x10\x01*\x91\x01\n\x0f\x43ryptoKeyFormat\x12!\n\x1d\x43RYPTO_KEY_FORMAT_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_DER\x10\x02\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_RAW\x10\x03\x12\x1f\n\x1a\x43RYPTO_KEY_FORMAT_SYMBOLIC\x10\x90N\"\x04\x08\x01\x10\x01*L\n\x0bPbkdfScheme\x12\x1c\n\x18PBKDF_SCHEME_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPBKDF_SCHEME_ARGON2ID_MODE1\x10\x01\x42SZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.crypto.v30.crypto_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZQgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/v30'
  _globals['_ENCRYPTIONPUBLICKEY'].fields_by_name['scheme']._loaded_options = None
  _globals['_ENCRYPTIONPUBLICKEY'].fields_by_name['scheme']._serialized_options = b'\030\001'
  _globals['_ENCRYPTIONPRIVATEKEY'].fields_by_name['scheme']._loaded_options = None
  _globals['_ENCRYPTIONPRIVATEKEY'].fields_by_name['scheme']._serialized_options = b'\030\001'
  _globals['_HASHALGORITHM']._serialized_start=3393
  _globals['_HASHALGORITHM']._serialized_end=3467
  _globals['_HMACALGORITHM']._serialized_start=3469
  _globals['_HMACALGORITHM']._serialized_end=3548
  _globals['_SIGNATUREFORMAT']._serialized_start=3550
  _globals['_SIGNATUREFORMAT']._serialized_end=3627
  _globals['_ENCRYPTIONKEYSPEC']._serialized_start=3629
  _globals['_ENCRYPTIONKEYSPEC']._serialized_end=3752
  _globals['_KEYPURPOSE']._serialized_start=3754
  _globals['_KEYPURPOSE']._serialized_end=3848
  _globals['_SIGNINGKEYSCHEME']._serialized_start=3851
  _globals['_SIGNINGKEYSCHEME']._serialized_end=4009
  _globals['_ENCRYPTIONALGORITHMSPEC']._serialized_start=4012
  _globals['_ENCRYPTIONALGORITHMSPEC']._serialized_end=4255
  _globals['_ENCRYPTIONKEYSCHEME']._serialized_start=4258
  _globals['_ENCRYPTIONKEYSCHEME']._serialized_end=4490
  _globals['_SYMMETRICKEYSCHEME']._serialized_start=4492
  _globals['_SYMMETRICKEYSCHEME']._serialized_end=4586
  _globals['_CRYPTOKEYFORMAT']._serialized_start=4589
  _globals['_CRYPTOKEYFORMAT']._serialized_end=4734
  _globals['_PBKDFSCHEME']._serialized_start=4736
  _globals['_PBKDFSCHEME']._serialized_end=4812
  _globals['_HMAC']._serialized_start=87
  _globals['_HMAC']._serialized_end=194
  _globals['_SALT']._serialized_start=196
  _globals['_SALT']._serialized_end=308
  _globals['_SIGNATURE']._serialized_start=311
  _globals['_SIGNATURE']._serialized_end=458
  _globals['_PUBLICKEY']._serialized_start=461
  _globals['_PUBLICKEY']._serialized_end=692
  _globals['_PUBLICKEYWITHNAME']._serialized_start=694
  _globals['_PUBLICKEYWITHNAME']._serialized_end=811
  _globals['_PRIVATEKEY']._serialized_start=814
  _globals['_PRIVATEKEY']._serialized_end=1052
  _globals['_SIGNINGPUBLICKEY']._serialized_start=1055
  _globals['_SIGNINGPUBLICKEY']._serialized_end=1265
  _globals['_SIGNINGPRIVATEKEY']._serialized_start=1268
  _globals['_SIGNINGPRIVATEKEY']._serialized_end=1491
  _globals['_SIGNINGKEYPAIR']._serialized_start=1494
  _globals['_SIGNINGKEYPAIR']._serialized_end=1683
  _globals['_ENCRYPTIONPUBLICKEY']._serialized_start=1686
  _globals['_ENCRYPTIONPUBLICKEY']._serialized_end=1988
  _globals['_ENCRYPTIONPRIVATEKEY']._serialized_start=1991
  _globals['_ENCRYPTIONPRIVATEKEY']._serialized_end=2306
  _globals['_ENCRYPTIONKEYPAIR']._serialized_start=2309
  _globals['_ENCRYPTIONKEYPAIR']._serialized_end=2507
  _globals['_REQUIREDENCRYPTIONSPECS']._serialized_start=2510
  _globals['_REQUIREDENCRYPTIONSPECS']._serialized_end=2703
  _globals['_CRYPTOKEYPAIR']._serialized_start=2706
  _globals['_CRYPTOKEYPAIR']._serialized_end=2930
  _globals['_SYMMETRICKEY']._serialized_start=2933
  _globals['_SYMMETRICKEY']._serialized_end=3122
  _globals['_PASSWORDBASEDENCRYPTED']._serialized_start=3125
  _globals['_PASSWORDBASEDENCRYPTED']._serialized_end=3391
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from typing import Any, AsyncIterable, Callable, Iterable, Tuple, TypeVar, Union, cast
from urllib.parse import urlparse

from grpc import (
    AuthMetadataContext,
    AuthMetadataPlugin,
    AuthMetadataPluginCallback,
    ChannelCredentials,
    composite_channel_credentials,
    metadata_call_credentials,
    ssl_channel_credentials,
)
from grpc.aio import (
    Channel,
    ClientCallDetails,
    ClientInterceptor,
    StreamStreamCall,
    StreamStreamClientInterceptor,
    StreamUnaryCall,
    StreamUnaryClientInterceptor,
    UnaryStreamCall,
    UnaryStreamClientInterceptor,
    UnaryUnaryCall,
    UnaryUnaryClientInterceptor,
    insecure_channel,
    secure_channel,
)

from ..auth import get_token
from ..config import Config

__all__ = ["create_channel"]

RequestType = TypeVar("RequestType")
RequestIterableType = Union[Iterable[Any], AsyncIterable[Any]]
ResponseIterableType = AsyncIterable[Any]


def create_channel(config: Config) -> Channel:
    """
    Create a :class:`Channel` for the specified configuration.
    """
    u = urlparse(config.url.url)

    options = [
        ("grpc.max_send_message_length", -1),
        ("grpc.max_receive_message_length", -1),
    ]
    if not config.url.use_http_proxy:
        options.append(("grpc.enable_http_proxy", 0))

    if (u.scheme in ("https", "grpcs")) or config.ssl:
        if config.ssl.ca is None and config.ssl.cert is not None:
            credentials = ssl_channel_credentials(root_certificates=config.ssl.cert)
        else:
            credentials = ssl_channel_credentials(
                root_certificates=config.ssl.ca,
                private_key=config.ssl.cert_key,
                certificate_chain=config.ssl.cert,
            )

        # The grpc Credential objects do not actually define a formal interface, and are
        # used interchangeably in the code.
        #
        # Additionally there are some incorrect rules in the grpc-stubs typing rules that force
        # us to work around the type system.
        credentials = cast(
            ChannelCredentials,
            composite_channel_credentials(
                credentials, metadata_call_credentials(GrpcAuth(config), name="auth gateway")
            ),
        )
        return secure_channel(u.netloc, credentials, tuple(options))

    else:
        # Python/C++ libraries refuse to allow "credentials" objects to be passed around on
        # non-TLS channels, but they don't check interceptors; use an interceptor to inject
        # an Authorization header instead
        #
        # There must be a distinct interceptor instance for each of
        # the four Request/Response arities. There is a known issue in
        # the underlying gRPC code that prevents reuse of a single
        # multiply-inherited interceptor.
        #
        # https://github.com/grpc/grpc/issues/31442
        return insecure_channel(
            u.netloc,
            options,
            interceptors=[
                cast(ClientInterceptor, GrpcAuthUnaryUnaryClientInterceptor(config)),
                cast(ClientInterceptor, GrpcAuthUnaryStreamClientInterceptor(config)),
                cast(ClientInterceptor, GrpcAuthStreamUnaryClientInterceptor(config)),
                cast(ClientInterceptor, GrpcAuthStreamStreamClientInterceptor(config)),
            ],
        )  # type: ignore


class GrpcAuth(AuthMetadataPlugin):
    def __init__(self, config: Config):
        self._config = config

    def __call__(self, context: AuthMetadataContext, callback: AuthMetadataPluginCallback):
        # This overly verbose type signature is here to satisfy mypy and grpc-stubs
        options = list[Tuple[str, Union[str, bytes]]]()

        token = get_token(self._config.access.token)
        if token:
            # note: gRPC headers MUST be lowercased
            options.append(("authorization", "Bearer " + token))

        callback(tuple(options), None)


class GrpcAuthInterceptor:
    """
    An interceptor that injects "Authorization" metadata into a request.

    This works around the fact that the C++ gRPC libraries (which Python is built on) highly
    discourage sending authorization data over the wire unless the connection is protected with TLS.
    """

    # NOTE: There are a number of typing errors in the grpc.aio classes, so we're ignoring a handful
    #  of lines until those problems are addressed.

    def __init__(self, config: Config):
        self._config = config

    def _modify_client_call_details(self, client_call_details: ClientCallDetails):
        if (
            client_call_details.metadata is not None
            and "authorization" not in client_call_details.metadata
        ):
            token = get_token(self._config.access.token)
            if token is not None:
                client_call_details.metadata.add("authorization", f"Bearer {token}")

        return client_call_details


class GrpcAuthUnaryUnaryClientInterceptor(GrpcAuthInterceptor, UnaryUnaryClientInterceptor):
    async def intercept_unary_unary(
        self,
        continuation: Callable[[ClientCallDetails, RequestType], UnaryUnaryCall],
        client_call_details: ClientCallDetails,
        request: RequestType,
    ) -> Union[UnaryUnaryCall, RequestType]:
        return await continuation(self._modify_client_call_details(client_call_details), request)


class GrpcAuthUnaryStreamClientInterceptor(GrpcAuthInterceptor, UnaryStreamClientInterceptor):
    async def intercept_unary_stream(
        self,
        continuation: Callable[[ClientCallDetails, RequestType], UnaryStreamCall],
        client_call_details: ClientCallDetails,
        request: RequestType,
    ) -> Union[ResponseIterableType, UnaryStreamCall]:
        return await continuation(  # type: ignore
            self._modify_client_call_details(client_call_details), request
        )


class GrpcAuthStreamUnaryClientInterceptor(GrpcAuthInterceptor, StreamUnaryClientInterceptor):
    async def intercept_stream_unary(  # type: ignore
        self,
        continuation: Callable[[ClientCallDetails, RequestType], StreamUnaryCall],
        client_call_details: ClientCallDetails,
        request_iterator: RequestIterableType,
    ) -> StreamUnaryCall:
        return await continuation(
            self._modify_client_call_details(client_call_details), request_iterator  # type: ignore
        )


class GrpcAuthStreamStreamClientInterceptor(GrpcAuthInterceptor, StreamStreamClientInterceptor):
    async def intercept_stream_stream(
        self,
        continuation: Callable[[ClientCallDetails, RequestType], StreamStreamCall],
        client_call_details: ClientCallDetails,
        request_iterator: RequestIterableType,
    ) -> Union[ResponseIterableType, StreamStreamCall]:
        return await continuation(  # type: ignore
            self._modify_client_call_details(client_call_details), request_iterator  # type: ignore
        )



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ViewType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MissingViewType: _ClassVar[ViewType]
    TransactionViewType: _ClassVar[ViewType]
    TransferOutViewType: _ClassVar[ViewType]
    TransferInViewType: _ClassVar[ViewType]
MissingViewType: ViewType
TransactionViewType: ViewType
TransferOutViewType: ViewType
TransferInViewType: ViewType

class SerializableContract(_message.Message):
    __slots__ = ("contract_id", "raw_contract_instance", "metadata", "ledger_create_time")
    class Metadata(_message.Message):
        __slots__ = ("non_maintainer_signatories", "non_signatory_stakeholders", "key", "maintainers")
        NON_MAINTAINER_SIGNATORIES_FIELD_NUMBER: _ClassVar[int]
        NON_SIGNATORY_STAKEHOLDERS_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        MAINTAINERS_FIELD_NUMBER: _ClassVar[int]
        non_maintainer_signatories: _containers.RepeatedScalarFieldContainer[str]
        non_signatory_stakeholders: _containers.RepeatedScalarFieldContainer[str]
        key: GlobalKey
        maintainers: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, non_maintainer_signatories: _Optional[_Iterable[str]] = ..., non_signatory_stakeholders: _Optional[_Iterable[str]] = ..., key: _Optional[_Union[GlobalKey, _Mapping]] = ..., maintainers: _Optional[_Iterable[str]] = ...) -> None: ...
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    RAW_CONTRACT_INSTANCE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    LEDGER_CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    raw_contract_instance: bytes
    metadata: SerializableContract.Metadata
    ledger_create_time: _timestamp_pb2.Timestamp
    def __init__(self, contract_id: _Optional[str] = ..., raw_contract_instance: _Optional[bytes] = ..., metadata: _Optional[_Union[SerializableContract.Metadata, _Mapping]] = ..., ledger_create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GlobalKey(_message.Message):
    __slots__ = ("template_id", "key")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    template_id: bytes
    key: bytes
    def __init__(self, template_id: _Optional[bytes] = ..., key: _Optional[bytes] = ...) -> None: ...

class DriverContractMetadata(_message.Message):
    __slots__ = ("contract_salt",)
    CONTRACT_SALT_FIELD_NUMBER: _ClassVar[int]
    contract_salt: _crypto_pb2.Salt
    def __init__(self, contract_salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/admin/metering_report_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/admin/metering_report_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:com/daml/ledger/api/v1/admin/metering_report_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x9d\x01\n\x18GetMeteringReportRequest\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\"\xa4\x02\n\x19GetMeteringReportResponse\x12P\n\x07request\x18\x01 \x01(\x0b\x32\x36.com.daml.ledger.api.v1.admin.GetMeteringReportRequestR\x07request\x12P\n\x16report_generation_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14reportGenerationTime\x12I\n\x14metering_report_json\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x12meteringReportJsonJ\x04\x08\x02\x10\x03R\x12participant_report2\x9e\x01\n\x15MeteringReportService\x12\x84\x01\n\x11GetMeteringReport\x12\x36.com.daml.ledger.api.v1.admin.GetMeteringReportRequest\x1a\x37.com.daml.ledger.api.v1.admin.GetMeteringReportResponseB\xa4\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\x18MeteringReportOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.admin.metering_report_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v1.adminB\030MeteringReportOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin'
  _globals['_GETMETERINGREPORTREQUEST']._serialized_start=156
  _globals['_GETMETERINGREPORTREQUEST']._serialized_end=313
  _globals['_GETMETERINGREPORTRESPONSE']._serialized_start=316
  _globals['_GETMETERINGREPORTRESPONSE']._serialized_end=608
  _globals['_METERINGREPORTSERVICE']._serialized_start=611
  _globals['_METERINGREPORTSERVICE']._serialized_end=769
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .transfer_service_pb2 import AdminTransferInRequest, AdminTransferInResponse, AdminTransferOutRequest, AdminTransferOutResponse, AdminTransferSearchQuery, AdminTransferSearchResponse

__all__ = [
    "TransferServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TransferServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TransferServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TransferServiceAsyncStub: ...  # type: ignore
    def TransferOut(self, __1: AdminTransferOutRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AdminTransferOutResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AdminTransferOutResponse]]: ...
    def TransferIn(self, __1: AdminTransferInRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AdminTransferInResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AdminTransferInResponse]]: ...
    def TransferSearch(self, __1: AdminTransferSearchQuery, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[AdminTransferSearchResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, AdminTransferSearchResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TransferServiceBlockingStub(TransferServiceStub):
    def TransferOut(self, __1: AdminTransferOutRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AdminTransferOutResponse: ...
    def TransferIn(self, __1: AdminTransferInRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AdminTransferInResponse: ...
    def TransferSearch(self, __1: AdminTransferSearchQuery, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> AdminTransferSearchResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TransferServiceAsyncStub(TransferServiceStub):
    def TransferOut(self, __1: AdminTransferOutRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AdminTransferOutResponse]: ...  # type: ignore
    def TransferIn(self, __1: AdminTransferInRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AdminTransferInResponse]: ...  # type: ignore
    def TransferSearch(self, __1: AdminTransferSearchQuery, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, AdminTransferSearchResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .value_pb2 import Enum, GenMap, Identifier, List, Optional, Record, RecordField, TextMap, Value, Variant
from .commands_pb2 import Command, Commands, CreateAndExerciseCommand, CreateCommand, DisclosedContract, ExerciseByKeyCommand, ExerciseCommand
from .offset_checkpoint_pb2 import DomainTime, OffsetCheckpoint
from .trace_context_pb2 import TraceContext
from .completion_pb2 import Completion
from .checkpoint_pb2 import Checkpoint
from .command_completion_service_pb2 import CompletionStreamRequest, CompletionStreamResponse
from .command_completion_service_pb2_grpc import CommandCompletionServiceStub
from .event_pb2 import ArchivedEvent, CreatedEvent, Event, ExercisedEvent, InterfaceView
from .transaction_pb2 import Transaction, TransactionTree, TreeEvent
from .command_service_pb2 import SubmitAndWaitForTransactionResponse, SubmitAndWaitForTransactionTreeResponse, SubmitAndWaitRequest, SubmitAndWaitResponse
from .command_service_pb2_grpc import CommandServiceStub
from .reassignment_command_pb2 import AssignCommand, ReassignmentCommand, UnassignCommand
from .command_submission_service_pb2 import SubmitReassignmentRequest, SubmitReassignmentResponse, SubmitRequest, SubmitResponse
from .command_submission_service_pb2_grpc import CommandSubmissionServiceStub
from .event_query_service_pb2 import Archived, Created, GetEventsByContractIdRequest, GetEventsByContractIdResponse
from .event_query_service_pb2_grpc import EventQueryServiceStub
from .experimental_features_pb2 import ExperimentalCommandInspectionService, ExperimentalFeatures, ExperimentalInteractiveSubmissionService, ExperimentalStaticTime
from .interactive_submission_data_pb2 import Create, DamlTransaction, GlobalKey, GlobalKeyWithMaintainers, Metadata, Node, PreparedTransaction
from .interactive_submission_service_pb2 import ExecuteSubmissionRequest, ExecuteSubmissionResponse, PartySignatures, PrepareSubmissionRequest, PrepareSubmissionResponse, Signature, SignatureFormat, SinglePartySignatures
from .interactive_submission_service_pb2_grpc import InteractiveSubmissionServiceStub
from .package_service_pb2 import GetPackageRequest, GetPackageResponse, GetPackageStatusRequest, GetPackageStatusResponse, HashFunction, ListPackagesRequest, ListPackagesResponse, PackageStatus
from .package_service_pb2_grpc import PackageServiceStub
from .participant_offset_pb2 import ParticipantOffset
from .reassignment_pb2 import AssignedEvent, Reassignment, UnassignedEvent
from .transaction_filter_pb2 import CumulativeFilter, Filters, InterfaceFilter, TemplateFilter, TransactionFilter, WildcardFilter
from .state_service_pb2 import ActiveContract, GetActiveContractsRequest, GetActiveContractsResponse, GetConnectedDomainsRequest, GetConnectedDomainsResponse, GetLatestPrunedOffsetsRequest, GetLatestPrunedOffsetsResponse, GetLedgerEndRequest, GetLedgerEndResponse, IncompleteAssigned, IncompleteUnassigned, ParticipantPermission
from .state_service_pb2_grpc import StateServiceStub
from .update_service_pb2 import GetTransactionByEventIdRequest, GetTransactionByIdRequest, GetTransactionResponse, GetTransactionTreeResponse, GetUpdateTreesResponse, GetUpdatesRequest, GetUpdatesResponse
from .update_service_pb2_grpc import UpdateServiceStub
from .version_service_pb2 import FeaturesDescriptor, GetLedgerApiVersionRequest, GetLedgerApiVersionResponse, OffsetCheckpointFeature, PartyManagementFeature, UserManagementFeature
from .version_service_pb2_grpc import VersionServiceStub

__all__ = [
    "ActiveContract",
    "Archived",
    "ArchivedEvent",
    "AssignCommand",
    "AssignedEvent",
    "Checkpoint",
    "Command",
    "CommandCompletionServiceStub",
    "CommandServiceStub",
    "CommandSubmissionServiceStub",
    "Commands",
    "Completion",
    "CompletionStreamRequest",
    "CompletionStreamResponse",
    "Create",
    "CreateAndExerciseCommand",
    "CreateCommand",
    "Created",
    "CreatedEvent",
    "CumulativeFilter",
    "DamlTransaction",
    "DisclosedContract",
    "DomainTime",
    "Enum",
    "Event",
    "EventQueryServiceStub",
    "ExecuteSubmissionRequest",
    "ExecuteSubmissionResponse",
    "ExerciseByKeyCommand",
    "ExerciseCommand",
    "ExercisedEvent",
    "ExperimentalCommandInspectionService",
    "ExperimentalFeatures",
    "ExperimentalInteractiveSubmissionService",
    "ExperimentalStaticTime",
    "FeaturesDescriptor",
    "Filters",
    "GenMap",
    "GetActiveContractsRequest",
    "GetActiveContractsResponse",
    "GetConnectedDomainsRequest",
    "GetConnectedDomainsResponse",
    "GetEventsByContractIdRequest",
    "GetEventsByContractIdResponse",
    "GetLatestPrunedOffsetsRequest",
    "GetLatestPrunedOffsetsResponse",
    "GetLedgerApiVersionRequest",
    "GetLedgerApiVersionResponse",
    "GetLedgerEndRequest",
    "GetLedgerEndResponse",
    "GetPackageRequest",
    "GetPackageResponse",
    "GetPackageStatusRequest",
    "GetPackageStatusResponse",
    "GetTransactionByEventIdRequest",
    "GetTransactionByIdRequest",
    "GetTransactionResponse",
    "GetTransactionTreeResponse",
    "GetUpdateTreesResponse",
    "GetUpdatesRequest",
    "GetUpdatesResponse",
    "GlobalKey",
    "GlobalKeyWithMaintainers",
    "HashFunction",
    "Identifier",
    "IncompleteAssigned",
    "IncompleteUnassigned",
    "InteractiveSubmissionServiceStub",
    "InterfaceFilter",
    "InterfaceView",
    "List",
    "ListPackagesRequest",
    "ListPackagesResponse",
    "Metadata",
    "Node",
    "OffsetCheckpoint",
    "OffsetCheckpointFeature",
    "Optional",
    "PackageServiceStub",
    "PackageStatus",
    "ParticipantOffset",
    "ParticipantPermission",
    "PartyManagementFeature",
    "PartySignatures",
    "PrepareSubmissionRequest",
    "PrepareSubmissionResponse",
    "PreparedTransaction",
    "Reassignment",
    "ReassignmentCommand",
    "Record",
    "RecordField",
    "Signature",
    "SignatureFormat",
    "SinglePartySignatures",
    "StateServiceStub",
    "SubmitAndWaitForTransactionResponse",
    "SubmitAndWaitForTransactionTreeResponse",
    "SubmitAndWaitRequest",
    "SubmitAndWaitResponse",
    "SubmitReassignmentRequest",
    "SubmitReassignmentResponse",
    "SubmitRequest",
    "SubmitResponse",
    "TemplateFilter",
    "TextMap",
    "TraceContext",
    "Transaction",
    "TransactionFilter",
    "TransactionTree",
    "TreeEvent",
    "UnassignCommand",
    "UnassignedEvent",
    "UpdateServiceStub",
    "UserManagementFeature",
    "Value",
    "Variant",
    "VersionServiceStub",
    "WildcardFilter",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from . import common_pb2 as _common_pb2
from . import merkle_pb2 as _merkle_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EncryptedViewMessage(_message.Message):
    __slots__ = ("view_tree", "submitter_participant_signature", "view_hash", "randomness", "domain_id", "view_type")
    VIEW_TREE_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_PARTICIPANT_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    VIEW_HASH_FIELD_NUMBER: _ClassVar[int]
    RANDOMNESS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    view_tree: bytes
    submitter_participant_signature: _crypto_pb2.Signature
    view_hash: bytes
    randomness: _containers.RepeatedCompositeFieldContainer[ParticipantRandomnessLookup]
    domain_id: str
    view_type: _common_pb2.ViewType
    def __init__(self, view_tree: _Optional[bytes] = ..., submitter_participant_signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., view_hash: _Optional[bytes] = ..., randomness: _Optional[_Iterable[_Union[ParticipantRandomnessLookup, _Mapping]]] = ..., domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ...) -> None: ...

class LightTransactionViewTree(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: _merkle_pb2.GenTransactionTree
    def __init__(self, tree: _Optional[_Union[_merkle_pb2.GenTransactionTree, _Mapping]] = ...) -> None: ...

class SubmitterMetadata(_message.Message):
    __slots__ = ("salt", "act_as", "application_id", "command_id", "submitter_participant", "submission_id", "dedup_period")
    SALT_FIELD_NUMBER: _ClassVar[int]
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    DEDUP_PERIOD_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    act_as: _containers.RepeatedScalarFieldContainer[str]
    application_id: str
    command_id: str
    submitter_participant: str
    submission_id: str
    dedup_period: DeduplicationPeriod
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., act_as: _Optional[_Iterable[str]] = ..., application_id: _Optional[str] = ..., command_id: _Optional[str] = ..., submitter_participant: _Optional[str] = ..., submission_id: _Optional[str] = ..., dedup_period: _Optional[_Union[DeduplicationPeriod, _Mapping]] = ...) -> None: ...

class DeduplicationPeriod(_message.Message):
    __slots__ = ("duration", "offset")
    DURATION_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    duration: _duration_pb2.Duration
    offset: bytes
    def __init__(self, duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., offset: _Optional[bytes] = ...) -> None: ...

class CommonMetadata(_message.Message):
    __slots__ = ("salt", "confirmation_policy", "domain_id", "uuid", "mediator_id")
    SALT_FIELD_NUMBER: _ClassVar[int]
    CONFIRMATION_POLICY_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_ID_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    confirmation_policy: bytes
    domain_id: str
    uuid: str
    mediator_id: str
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., confirmation_policy: _Optional[bytes] = ..., domain_id: _Optional[str] = ..., uuid: _Optional[str] = ..., mediator_id: _Optional[str] = ...) -> None: ...

class ParticipantMetadata(_message.Message):
    __slots__ = ("salt", "ledger_time", "submission_time", "workflow_id")
    SALT_FIELD_NUMBER: _ClassVar[int]
    LEDGER_TIME_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_TIME_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    ledger_time: _timestamp_pb2.Timestamp
    submission_time: _timestamp_pb2.Timestamp
    workflow_id: str
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., ledger_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., submission_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., workflow_id: _Optional[str] = ...) -> None: ...

class ViewNode(_message.Message):
    __slots__ = ("view_common_data", "view_participant_data", "subviews")
    VIEW_COMMON_DATA_FIELD_NUMBER: _ClassVar[int]
    VIEW_PARTICIPANT_DATA_FIELD_NUMBER: _ClassVar[int]
    SUBVIEWS_FIELD_NUMBER: _ClassVar[int]
    view_common_data: _merkle_pb2.BlindableNode
    view_participant_data: _merkle_pb2.BlindableNode
    subviews: _containers.RepeatedCompositeFieldContainer[_merkle_pb2.BlindableNode]
    def __init__(self, view_common_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ..., view_participant_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ..., subviews: _Optional[_Iterable[_Union[_merkle_pb2.BlindableNode, _Mapping]]] = ...) -> None: ...

class ViewCommonData(_message.Message):
    __slots__ = ("salt", "informees", "threshold")
    SALT_FIELD_NUMBER: _ClassVar[int]
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    informees: _containers.RepeatedCompositeFieldContainer[Informee]
    threshold: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., informees: _Optional[_Iterable[_Union[Informee, _Mapping]]] = ..., threshold: _Optional[int] = ...) -> None: ...

class Informee(_message.Message):
    __slots__ = ("party", "weight")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    party: str
    weight: int
    def __init__(self, party: _Optional[str] = ..., weight: _Optional[int] = ...) -> None: ...

class ViewParticipantData(_message.Message):
    __slots__ = ("salt", "core_inputs", "created_core", "created_in_subview_archived_in_core", "resolved_keys", "action_description", "rollback_context")
    class CreatedContract(_message.Message):
        __slots__ = ("contract", "consumed_in_core", "rolled_back")
        CONTRACT_FIELD_NUMBER: _ClassVar[int]
        CONSUMED_IN_CORE_FIELD_NUMBER: _ClassVar[int]
        ROLLED_BACK_FIELD_NUMBER: _ClassVar[int]
        contract: _common_pb2.SerializableContract
        consumed_in_core: bool
        rolled_back: bool
        def __init__(self, contract: _Optional[_Union[_common_pb2.SerializableContract, _Mapping]] = ..., consumed_in_core: bool = ..., rolled_back: bool = ...) -> None: ...
    class InputContract(_message.Message):
        __slots__ = ("contract", "consumed")
        CONTRACT_FIELD_NUMBER: _ClassVar[int]
        CONSUMED_FIELD_NUMBER: _ClassVar[int]
        contract: _common_pb2.SerializableContract
        consumed: bool
        def __init__(self, contract: _Optional[_Union[_common_pb2.SerializableContract, _Mapping]] = ..., consumed: bool = ...) -> None: ...
    class ResolvedKey(_message.Message):
        __slots__ = ("key", "contract_id", "free")
        KEY_FIELD_NUMBER: _ClassVar[int]
        CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        FREE_FIELD_NUMBER: _ClassVar[int]
        key: _common_pb2.GlobalKey
        contract_id: str
        free: ViewParticipantData.FreeKey
        def __init__(self, key: _Optional[_Union[_common_pb2.GlobalKey, _Mapping]] = ..., contract_id: _Optional[str] = ..., free: _Optional[_Union[ViewParticipantData.FreeKey, _Mapping]] = ...) -> None: ...
    class FreeKey(_message.Message):
        __slots__ = ("maintainers",)
        MAINTAINERS_FIELD_NUMBER: _ClassVar[int]
        maintainers: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, maintainers: _Optional[_Iterable[str]] = ...) -> None: ...
    class RollbackContext(_message.Message):
        __slots__ = ("rollback_scope", "next_child")
        ROLLBACK_SCOPE_FIELD_NUMBER: _ClassVar[int]
        NEXT_CHILD_FIELD_NUMBER: _ClassVar[int]
        rollback_scope: _containers.RepeatedScalarFieldContainer[int]
        next_child: int
        def __init__(self, rollback_scope: _Optional[_Iterable[int]] = ..., next_child: _Optional[int] = ...) -> None: ...
    SALT_FIELD_NUMBER: _ClassVar[int]
    CORE_INPUTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_CORE_FIELD_NUMBER: _ClassVar[int]
    CREATED_IN_SUBVIEW_ARCHIVED_IN_CORE_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_KEYS_FIELD_NUMBER: _ClassVar[int]
    ACTION_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ROLLBACK_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    core_inputs: _containers.RepeatedCompositeFieldContainer[ViewParticipantData.InputContract]
    created_core: _containers.RepeatedCompositeFieldContainer[ViewParticipantData.CreatedContract]
    created_in_subview_archived_in_core: _containers.RepeatedScalarFieldContainer[str]
    resolved_keys: _containers.RepeatedCompositeFieldContainer[ViewParticipantData.ResolvedKey]
    action_description: ActionDescription
    rollback_context: ViewParticipantData.RollbackContext
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., core_inputs: _Optional[_Iterable[_Union[ViewParticipantData.InputContract, _Mapping]]] = ..., created_core: _Optional[_Iterable[_Union[ViewParticipantData.CreatedContract, _Mapping]]] = ..., created_in_subview_archived_in_core: _Optional[_Iterable[str]] = ..., resolved_keys: _Optional[_Iterable[_Union[ViewParticipantData.ResolvedKey, _Mapping]]] = ..., action_description: _Optional[_Union[ActionDescription, _Mapping]] = ..., rollback_context: _Optional[_Union[ViewParticipantData.RollbackContext, _Mapping]] = ...) -> None: ...

class ActionDescription(_message.Message):
    __slots__ = ("create", "exercise", "fetch", "lookup_by_key")
    class CreateActionDescription(_message.Message):
        __slots__ = ("contract_id", "node_seed", "version")
        CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        NODE_SEED_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        contract_id: str
        node_seed: bytes
        version: str
        def __init__(self, contract_id: _Optional[str] = ..., node_seed: _Optional[bytes] = ..., version: _Optional[str] = ...) -> None: ...
    class ExerciseActionDescription(_message.Message):
        __slots__ = ("input_contract_id", "choice", "chosen_value", "actors", "by_key", "node_seed", "version", "failed")
        INPUT_CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        CHOICE_FIELD_NUMBER: _ClassVar[int]
        CHOSEN_VALUE_FIELD_NUMBER: _ClassVar[int]
        ACTORS_FIELD_NUMBER: _ClassVar[int]
        BY_KEY_FIELD_NUMBER: _ClassVar[int]
        NODE_SEED_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        input_contract_id: str
        choice: str
        chosen_value: bytes
        actors: _containers.RepeatedScalarFieldContainer[str]
        by_key: bool
        node_seed: bytes
        version: str
        failed: bool
        def __init__(self, input_contract_id: _Optional[str] = ..., choice: _Optional[str] = ..., chosen_value: _Optional[bytes] = ..., actors: _Optional[_Iterable[str]] = ..., by_key: bool = ..., node_seed: _Optional[bytes] = ..., version: _Optional[str] = ..., failed: bool = ...) -> None: ...
    class FetchActionDescription(_message.Message):
        __slots__ = ("input_contract_id", "actors", "by_key", "version")
        INPUT_CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        ACTORS_FIELD_NUMBER: _ClassVar[int]
        BY_KEY_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        input_contract_id: str
        actors: _containers.RepeatedScalarFieldContainer[str]
        by_key: bool
        version: str
        def __init__(self, input_contract_id: _Optional[str] = ..., actors: _Optional[_Iterable[str]] = ..., by_key: bool = ..., version: _Optional[str] = ...) -> None: ...
    class LookupByKeyActionDescription(_message.Message):
        __slots__ = ("key",)
        KEY_FIELD_NUMBER: _ClassVar[int]
        key: _common_pb2.GlobalKey
        def __init__(self, key: _Optional[_Union[_common_pb2.GlobalKey, _Mapping]] = ...) -> None: ...
    CREATE_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_FIELD_NUMBER: _ClassVar[int]
    FETCH_FIELD_NUMBER: _ClassVar[int]
    LOOKUP_BY_KEY_FIELD_NUMBER: _ClassVar[int]
    create: ActionDescription.CreateActionDescription
    exercise: ActionDescription.ExerciseActionDescription
    fetch: ActionDescription.FetchActionDescription
    lookup_by_key: ActionDescription.LookupByKeyActionDescription
    def __init__(self, create: _Optional[_Union[ActionDescription.CreateActionDescription, _Mapping]] = ..., exercise: _Optional[_Union[ActionDescription.ExerciseActionDescription, _Mapping]] = ..., fetch: _Optional[_Union[ActionDescription.FetchActionDescription, _Mapping]] = ..., lookup_by_key: _Optional[_Union[ActionDescription.LookupByKeyActionDescription, _Mapping]] = ...) -> None: ...

class ParticipantRandomnessLookup(_message.Message):
    __slots__ = ("participant", "randomness")
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    RANDOMNESS_FIELD_NUMBER: _ClassVar[int]
    participant: str
    randomness: bytes
    def __init__(self, participant: _Optional[str] = ..., randomness: _Optional[bytes] = ...) -> None: ...

class InformeeMessage(_message.Message):
    __slots__ = ("full_informee_tree",)
    FULL_INFORMEE_TREE_FIELD_NUMBER: _ClassVar[int]
    full_informee_tree: FullInformeeTree
    def __init__(self, full_informee_tree: _Optional[_Union[FullInformeeTree, _Mapping]] = ...) -> None: ...

class FullInformeeTree(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: _merkle_pb2.GenTransactionTree
    def __init__(self, tree: _Optional[_Union[_merkle_pb2.GenTransactionTree, _Mapping]] = ...) -> None: ...

class RootHashMessage(_message.Message):
    __slots__ = ("root_hash", "domain_id", "view_type", "payload")
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    root_hash: bytes
    domain_id: str
    view_type: _common_pb2.ViewType
    payload: bytes
    def __init__(self, root_hash: _Optional[bytes] = ..., domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ..., payload: _Optional[bytes] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....admin.domain.v30 import sequencer_connection_pb2 as _sequencer_connection_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetConnectionRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetConnectionResponse(_message.Message):
    __slots__ = ("sequencer_connections",)
    SEQUENCER_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    sequencer_connections: _sequencer_connection_pb2.SequencerConnections
    def __init__(self, sequencer_connections: _Optional[_Union[_sequencer_connection_pb2.SequencerConnections, _Mapping]] = ...) -> None: ...

class SetConnectionRequest(_message.Message):
    __slots__ = ("sequencer_connections", "sequencer_connection_validation")
    SEQUENCER_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTION_VALIDATION_FIELD_NUMBER: _ClassVar[int]
    sequencer_connections: _sequencer_connection_pb2.SequencerConnections
    sequencer_connection_validation: _sequencer_connection_pb2.SequencerConnectionValidation
    def __init__(self, sequencer_connections: _Optional[_Union[_sequencer_connection_pb2.SequencerConnections, _Mapping]] = ..., sequencer_connection_validation: _Optional[_Union[_sequencer_connection_pb2.SequencerConnectionValidation, str]] = ...) -> None: ...

class SetConnectionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/transfer_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/transfer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v0 import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transfer__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/participant/admin/v0/transfer_service.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a>com/digitalasset/canton/protocol/v0/participant_transfer.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x02\n\x17\x41\x64minTransferOutRequest\x12)\n\x10submitting_party\x18\x01 \x01(\tR\x0fsubmittingParty\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12#\n\rorigin_domain\x18\x03 \x01(\tR\x0coriginDomain\x12#\n\rtarget_domain\x18\x04 \x01(\tR\x0ctargetDomain\x12%\n\x0e\x61pplication_id\x18\x05 \x01(\tR\rapplicationId\x12#\n\rsubmission_id\x18\x06 \x01(\tR\x0csubmissionId\x12\x1f\n\x0bworkflow_id\x18\x07 \x01(\tR\nworkflowId\x12\x1d\n\ncommand_id\x18\x08 \x01(\tR\tcommandId\"l\n\x18\x41\x64minTransferOutResponse\x12P\n\x0btransfer_id\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\ntransferId\"\xcb\x02\n\x16\x41\x64minTransferInRequest\x12.\n\x13submitting_party_id\x18\x01 \x01(\tR\x11submittingPartyId\x12#\n\rtarget_domain\x18\x02 \x01(\tR\x0ctargetDomain\x12P\n\x0btransfer_id\x18\x03 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\ntransferId\x12%\n\x0e\x61pplication_id\x18\x04 \x01(\tR\rapplicationId\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\x12\x1f\n\x0bworkflow_id\x18\x06 \x01(\tR\nworkflowId\x12\x1d\n\ncommand_id\x18\x07 \x01(\tR\tcommandId\"\x19\n\x17\x41\x64minTransferInResponse\"\x86\x02\n\x18\x41\x64minTransferSearchQuery\x12#\n\rsearch_domain\x18\x01 \x01(\tR\x0csearchDomain\x12\x30\n\x14\x66ilter_origin_domain\x18\x02 \x01(\tR\x12\x66ilterOriginDomain\x12\x45\n\x10\x66ilter_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66ilterTimestamp\x12\x36\n\x17\x66ilter_submitting_party\x18\x04 \x01(\tR\x15\x66ilterSubmittingParty\x12\x14\n\x05limit\x18\x05 \x01(\x03R\x05limit\"\x93\x04\n\x1b\x41\x64minTransferSearchResponse\x12x\n\x07results\x18\x01 \x03(\x0b\x32^.com.digitalasset.canton.participant.admin.v0.AdminTransferSearchResponse.TransferSearchResultR\x07results\x1a\xf9\x02\n\x14TransferSearchResult\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12P\n\x0btransfer_id\x18\x02 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\ntransferId\x12#\n\rorigin_domain\x18\x03 \x01(\tR\x0coriginDomain\x12#\n\rtarget_domain\x18\x04 \x01(\tR\x0ctargetDomain\x12)\n\x10submitting_party\x18\x05 \x01(\tR\x0fsubmittingParty\x12\x31\n\x15ready_for_transfer_in\x18\x06 \x01(\x08R\x12readyForTransferIn\x12\x46\n\x11target_time_proof\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0ftargetTimeProof2\xf2\x03\n\x0fTransferService\x12\x9c\x01\n\x0bTransferOut\x12\x45.com.digitalasset.canton.participant.admin.v0.AdminTransferOutRequest\x1a\x46.com.digitalasset.canton.participant.admin.v0.AdminTransferOutResponse\x12\x99\x01\n\nTransferIn\x12\x44.com.digitalasset.canton.participant.admin.v0.AdminTransferInRequest\x1a\x45.com.digitalasset.canton.participant.admin.v0.AdminTransferInResponse\x12\xa3\x01\n\x0eTransferSearch\x12\x46.com.digitalasset.canton.participant.admin.v0.AdminTransferSearchQuery\x1aI.com.digitalasset.canton.participant.admin.v0.AdminTransferSearchResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.transfer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_ADMINTRANSFEROUTREQUEST']._serialized_start=215
  _globals['_ADMINTRANSFEROUTREQUEST']._serialized_end=530
  _globals['_ADMINTRANSFEROUTRESPONSE']._serialized_start=532
  _globals['_ADMINTRANSFEROUTRESPONSE']._serialized_end=640
  _globals['_ADMINTRANSFERINREQUEST']._serialized_start=643
  _globals['_ADMINTRANSFERINREQUEST']._serialized_end=974
  _globals['_ADMINTRANSFERINRESPONSE']._serialized_start=976
  _globals['_ADMINTRANSFERINRESPONSE']._serialized_end=1001
  _globals['_ADMINTRANSFERSEARCHQUERY']._serialized_start=1004
  _globals['_ADMINTRANSFERSEARCHQUERY']._serialized_end=1266
  _globals['_ADMINTRANSFERSEARCHRESPONSE']._serialized_start=1269
  _globals['_ADMINTRANSFERSEARCHRESPONSE']._serialized_end=1800
  _globals['_ADMINTRANSFERSEARCHRESPONSE_TRANSFERSEARCHRESULT']._serialized_start=1423
  _globals['_ADMINTRANSFERSEARCHRESPONSE_TRANSFERSEARCHRESULT']._serialized_end=1800
  _globals['_TRANSFERSERVICE']._serialized_start=1803
  _globals['_TRANSFERSERVICE']._serialized_end=2301
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import common_pb2 as _common_pb2
from . import mediator_response_pb2 as _mediator_response_pb2
from . import merkle_pb2 as _merkle_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionResultMessage(_message.Message):
    __slots__ = ("request_id", "verdict", "notification_tree")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_TREE_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    verdict: Verdict
    notification_tree: InformeeTree
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., verdict: _Optional[_Union[Verdict, _Mapping]] = ..., notification_tree: _Optional[_Union[InformeeTree, _Mapping]] = ...) -> None: ...

class Verdict(_message.Message):
    __slots__ = ("approve", "validator_reject", "mediator_reject", "timeout")
    APPROVE_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_REJECT_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_REJECT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    approve: _empty_pb2.Empty
    validator_reject: RejectionReasons
    mediator_reject: MediatorRejection
    timeout: _empty_pb2.Empty
    def __init__(self, approve: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., validator_reject: _Optional[_Union[RejectionReasons, _Mapping]] = ..., mediator_reject: _Optional[_Union[MediatorRejection, _Mapping]] = ..., timeout: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class RejectionReasons(_message.Message):
    __slots__ = ("reasons",)
    REASONS_FIELD_NUMBER: _ClassVar[int]
    reasons: _containers.RepeatedCompositeFieldContainer[RejectionReason]
    def __init__(self, reasons: _Optional[_Iterable[_Union[RejectionReason, _Mapping]]] = ...) -> None: ...

class RejectionReason(_message.Message):
    __slots__ = ("parties", "reject")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    REJECT_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    reject: _mediator_response_pb2.LocalReject
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., reject: _Optional[_Union[_mediator_response_pb2.LocalReject, _Mapping]] = ...) -> None: ...

class MediatorRejection(_message.Message):
    __slots__ = ("code", "reason")
    class Code(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        MissingCode: _ClassVar[MediatorRejection.Code]
        InformeesNotHostedOnActiveParticipant: _ClassVar[MediatorRejection.Code]
        NotEnoughConfirmingParties: _ClassVar[MediatorRejection.Code]
        ViewThresholdBelowMinimumThreshold: _ClassVar[MediatorRejection.Code]
        InvalidRootHashMessage: _ClassVar[MediatorRejection.Code]
        Timeout: _ClassVar[MediatorRejection.Code]
        WrongDeclaredMediator: _ClassVar[MediatorRejection.Code]
        NonUniqueRequestUuid: _ClassVar[MediatorRejection.Code]
    MissingCode: MediatorRejection.Code
    InformeesNotHostedOnActiveParticipant: MediatorRejection.Code
    NotEnoughConfirmingParties: MediatorRejection.Code
    ViewThresholdBelowMinimumThreshold: MediatorRejection.Code
    InvalidRootHashMessage: MediatorRejection.Code
    Timeout: MediatorRejection.Code
    WrongDeclaredMediator: MediatorRejection.Code
    NonUniqueRequestUuid: MediatorRejection.Code
    CODE_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    code: MediatorRejection.Code
    reason: str
    def __init__(self, code: _Optional[_Union[MediatorRejection.Code, str]] = ..., reason: _Optional[str] = ...) -> None: ...

class InformeeTree(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: _merkle_pb2.GenTransactionTree
    def __init__(self, tree: _Optional[_Union[_merkle_pb2.GenTransactionTree, _Mapping]] = ...) -> None: ...

class MalformedMediatorRequestResult(_message.Message):
    __slots__ = ("request_id", "domain_id", "view_type", "rejection")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    REJECTION_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    domain_id: str
    view_type: _common_pb2.ViewType
    rejection: MediatorRejection
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ..., rejection: _Optional[_Union[MediatorRejection, _Mapping]] = ...) -> None: ...

class TransferResult(_message.Message):
    __slots__ = ("request_id", "origin_domain", "target_domain", "informees", "verdict")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    origin_domain: str
    target_domain: str
    informees: _containers.RepeatedScalarFieldContainer[str]
    verdict: Verdict
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., origin_domain: _Optional[str] = ..., target_domain: _Optional[str] = ..., informees: _Optional[_Iterable[str]] = ..., verdict: _Optional[_Union[Verdict, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencing_pb2 import Batch, CompressedBatch, DeliverErrorReason, DynamicDomainParameters, Envelope, Handshake, PossiblyIgnoredSequencedEvent, Recipients, RecipientsTree, SequencedEvent, ServiceAgreement, SignedContent, StaticDomainParameters, SubmissionRequest
from .topology_ext_pb2 import TopologyTransactions
from .common_pb2 import DriverContractMetadata, GlobalKey, SerializableContract, ViewType
from .merkle_pb2 import BlindableNode, GenTransactionTree, MerkleSeq, MerkleSeqElement
from .participant_transfer_pb2 import TransferId, TransferInCommonData, TransferInMediatorMessage, TransferInView, TransferOutCommonData, TransferOutMediatorMessage, TransferOutView, TransferViewTree
from .participant_transaction_pb2 import ActionDescription, CommonMetadata, DeduplicationPeriod, EncryptedViewMessage, FullInformeeTree, Informee, InformeeMessage, LightTransactionViewTree, ParticipantMetadata, ParticipantRandomnessLookup, RootHashMessage, SubmitterMetadata, ViewCommonData, ViewNode, ViewParticipantData
from .acs_commitments_pb2 import AcsCommitment
from .causality_pb2 import CausalityMessage, CausalityUpdate, TransactionUpdate, TransferInUpdate, TransferOutUpdate, VectorClock
from .mediator_response_pb2 import LocalReject, LocalVerdict, MediatorResponse
from .mediator_pb2 import InformeeTree, MalformedMediatorRequestResult, MediatorRejection, RejectionReason, RejectionReasons, TransactionResultMessage, TransferResult, Verdict
from .topology_pb2 import DomainGovernanceTransaction, DomainParametersChange, DomainTopologyTransactionMessage, IdentifierDelegation, LegalIdentityClaim, MediatorDomainState, NamespaceDelegation, OwnerToKeyMapping, ParticipantPermission, ParticipantState, PartyToParticipant, RegisterTopologyTransactionRequest, RegisterTopologyTransactionResponse, RequestSide, SignedLegalIdentityClaim, SignedTopologyTransaction, TopologyChangeOp, TopologyStateUpdate, TopologyTransaction, TrustLevel, VettedPackages
from .quorum_pb2 import PartyIndexAndWeight, Quorum, TrustParty
from .storage_pb2 import StoredParties
from .synchronization_pb2 import EnvelopeContent, SignedProtocolMessage
from .versioned_google_rpc_status_pb2 import VersionedStatus

__all__ = [
    "AcsCommitment",
    "ActionDescription",
    "Batch",
    "BlindableNode",
    "CausalityMessage",
    "CausalityUpdate",
    "CommonMetadata",
    "CompressedBatch",
    "DeduplicationPeriod",
    "DeliverErrorReason",
    "DomainGovernanceTransaction",
    "DomainParametersChange",
    "DomainTopologyTransactionMessage",
    "DriverContractMetadata",
    "DynamicDomainParameters",
    "EncryptedViewMessage",
    "Envelope",
    "EnvelopeContent",
    "FullInformeeTree",
    "GenTransactionTree",
    "GlobalKey",
    "Handshake",
    "IdentifierDelegation",
    "Informee",
    "InformeeMessage",
    "InformeeTree",
    "LegalIdentityClaim",
    "LightTransactionViewTree",
    "LocalReject",
    "LocalVerdict",
    "MalformedMediatorRequestResult",
    "MediatorDomainState",
    "MediatorRejection",
    "MediatorResponse",
    "MerkleSeq",
    "MerkleSeqElement",
    "NamespaceDelegation",
    "OwnerToKeyMapping",
    "ParticipantMetadata",
    "ParticipantPermission",
    "ParticipantRandomnessLookup",
    "ParticipantState",
    "PartyIndexAndWeight",
    "PartyToParticipant",
    "PossiblyIgnoredSequencedEvent",
    "Quorum",
    "Recipients",
    "RecipientsTree",
    "RegisterTopologyTransactionRequest",
    "RegisterTopologyTransactionResponse",
    "RejectionReason",
    "RejectionReasons",
    "RequestSide",
    "RootHashMessage",
    "SequencedEvent",
    "SerializableContract",
    "ServiceAgreement",
    "SignedContent",
    "SignedLegalIdentityClaim",
    "SignedProtocolMessage",
    "SignedTopologyTransaction",
    "StaticDomainParameters",
    "StoredParties",
    "SubmissionRequest",
    "SubmitterMetadata",
    "TopologyChangeOp",
    "TopologyStateUpdate",
    "TopologyTransaction",
    "TopologyTransactions",
    "TransactionResultMessage",
    "TransactionUpdate",
    "TransferId",
    "TransferInCommonData",
    "TransferInMediatorMessage",
    "TransferInUpdate",
    "TransferInView",
    "TransferOutCommonData",
    "TransferOutMediatorMessage",
    "TransferOutUpdate",
    "TransferOutView",
    "TransferResult",
    "TransferViewTree",
    "TrustLevel",
    "TrustParty",
    "VectorClock",
    "Verdict",
    "VersionedStatus",
    "VettedPackages",
    "ViewCommonData",
    "ViewNode",
    "ViewParticipantData",
    "ViewType",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .common_pb2 import SerializableContract
from .domain_params_pb2 import CatchUpConfig, DynamicDomainParameters
from .mediator_pb2 import MalformedMediatorRequestResult, MediatorReject, ParticipantReject, RejectionReason, TransactionResultMessage, TransferResult, Verdict
from .mediator_response_pb2 import MediatorResponse, MerkleSeqIndex, ViewPosition
from .participant_transaction_pb2 import ActionDescription, CreatedContract, EncryptedViewMessage, InputContract, SessionKeyLookup, ViewCommonData, ViewParticipantData
from .participant_transfer_pb2 import TransferInView
from .synchronization_pb2 import EnvelopeContent
from .topology_pb2 import DomainGovernanceTransaction, DomainParametersChange, TopologyTransaction

__all__ = [
    "ActionDescription",
    "CatchUpConfig",
    "CreatedContract",
    "DomainGovernanceTransaction",
    "DomainParametersChange",
    "DynamicDomainParameters",
    "EncryptedViewMessage",
    "EnvelopeContent",
    "InputContract",
    "MalformedMediatorRequestResult",
    "MediatorReject",
    "MediatorResponse",
    "MerkleSeqIndex",
    "ParticipantReject",
    "RejectionReason",
    "SerializableContract",
    "SessionKeyLookup",
    "TopologyTransaction",
    "TransactionResultMessage",
    "TransferInView",
    "TransferResult",
    "Verdict",
    "ViewCommonData",
    "ViewParticipantData",
    "ViewPosition",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v3/mediator.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v3/mediator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v2 import mediator_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v2_dot_mediator__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/digitalasset/canton/protocol/v3/mediator.proto\x12#com.digitalasset.canton.protocol.v3\x1a\x32\x63om/digitalasset/canton/protocol/v2/mediator.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x96\x02\n\x07Verdict\x12\x32\n\x07\x61pprove\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07\x61pprove\x12g\n\x12participant_reject\x18\x02 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v2.ParticipantRejectH\x00R\x11participantReject\x12^\n\x0fmediator_reject\x18\x03 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v2.MediatorRejectH\x00R\x0emediatorRejectB\x0e\n\x0csome_verdict\"\xd7\x01\n\x18TransactionResultMessage\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12\x46\n\x07verdict\x18\x02 \x01(\x0b\x32,.com.digitalasset.canton.protocol.v3.VerdictR\x07verdict\x12\x1b\n\troot_hash\x18\x03 \x01(\x0cR\x08rootHash\x12\x1b\n\tdomain_id\x18\x04 \x01(\tR\x08\x64omainId\"\x89\x02\n\x0eTransferResult\x12\x39\n\nrequest_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trequestId\x12%\n\rsource_domain\x18\x02 \x01(\tH\x00R\x0csourceDomain\x12%\n\rtarget_domain\x18\x03 \x01(\tH\x00R\x0ctargetDomain\x12\x1c\n\tinformees\x18\x04 \x03(\tR\tinformees\x12\x46\n\x07verdict\x18\x05 \x01(\x0b\x32,.com.digitalasset.canton.protocol.v3.VerdictR\x07verdictB\x08\n\x06\x64omainBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v3.mediator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v3'
  _globals['_VERDICT']._serialized_start=206
  _globals['_VERDICT']._serialized_end=484
  _globals['_TRANSACTIONRESULTMESSAGE']._serialized_start=487
  _globals['_TRANSACTIONRESULTMESSAGE']._serialized_end=702
  _globals['_TRANSFERRESULT']._serialized_start=705
  _globals['_TRANSFERRESULT']._serialized_end=970
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v30/ledger_sync_event.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/protocol/v30/ledger_sync_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transaction__pb2
from ....protocol.v30 import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transfer__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHcom/digitalasset/canton/participant/protocol/v30/ledger_sync_event.proto\x12\x30\x63om.digitalasset.canton.participant.protocol.v30\x1a\x42\x63om/digitalasset/canton/protocol/v30/participant_transaction.proto\x1a?com/digitalasset/canton/protocol/v30/participant_transfer.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x8d\n\n\x0fLedgerSyncEvent\x12\x88\x01\n\x1aparty_added_to_participant\x18\x01 \x01(\x0b\x32I.com.digitalasset.canton.participant.protocol.v30.PartyAddedToParticipantH\x00R\x17partyAddedToParticipant\x12z\n\x14transaction_accepted\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.participant.protocol.v30.TransactionAcceptedH\x00R\x13transactionAccepted\x12n\n\x10\x63ommand_rejected\x18\x03 \x01(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v30.CommandRejectedH\x00R\x0f\x63ommandRejected\x12\x87\x01\n\x19party_allocation_rejected\x18\x04 \x01(\x0b\x32I.com.digitalasset.canton.participant.protocol.v30.PartyAllocationRejectedH\x00R\x17partyAllocationRejected\x12k\n\x0ftransferred_out\x18\x05 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.TransferredOutH\x00R\x0etransferredOut\x12h\n\x0etransferred_in\x18\x06 \x01(\x0b\x32?.com.digitalasset.canton.participant.protocol.v30.TransferredInH\x00R\rtransferredIn\x12k\n\x0f\x63ontracts_added\x18\x07 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.ContractsAddedH\x00R\x0e\x63ontractsAdded\x12n\n\x10\x63ontracts_purged\x18\x08 \x01(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v30.ContractsPurgedH\x00R\x0f\x63ontractsPurged\x12r\n\rparties_added\x18\t \x01(\x0b\x32K.com.digitalasset.canton.participant.protocol.v30.PartiesAddedToParticipantH\x00R\x0cpartiesAdded\x12z\n\x0fparties_removed\x18\n \x01(\x0b\x32O.com.digitalasset.canton.participant.protocol.v30.PartiesRemovedFromParticipantH\x00R\x0epartiesRemoved\x12L\n\x04init\x18\x0b \x01(\x0b\x32\x36.com.digitalasset.canton.participant.protocol.v30.InitH\x00R\x04initB\x07\n\x05value\"\xbf\x01\n\x17PartyAddedToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12%\n\x0eparticipant_id\x18\x03 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xb1\x01\n\x17PartyAllocationRejected\x12#\n\rsubmission_id\x18\x01 \x01(\tR\x0csubmissionId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x03 \x01(\x03R\nrecordTime\x12)\n\x10rejection_reason\x18\x04 \x01(\tR\x0frejectionReason\"\xc8\x06\n\x13TransactionAccepted\x12i\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12l\n\x10transaction_meta\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.participant.protocol.v30.TransactionMetaR\x0ftransactionMeta\x12 \n\x0btransaction\x18\x03 \x01(\x0cR\x0btransaction\x12%\n\x0etransaction_id\x18\x04 \x01(\tR\rtransactionId\x12\x1f\n\x0brecord_time\x18\x05 \x01(\x03R\nrecordTime\x12q\n\x12\x64ivulged_contracts\x18\x06 \x03(\x0b\x32\x42.com.digitalasset.canton.participant.protocol.v30.DivulgedContractR\x11\x64ivulgedContracts\x12\x63\n\rblinding_info\x18\x07 \x01(\x0b\x32>.com.digitalasset.canton.participant.protocol.v30.BlindingInfoR\x0c\x62lindingInfo\x12\x88\x01\n\x11\x63ontract_metadata\x18\x08 \x03(\x0b\x32[.com.digitalasset.canton.participant.protocol.v30.TransactionAccepted.ContractMetadataEntryR\x10\x63ontractMetadata\x12)\n\x10hosted_witnesses\x18\t \x03(\tR\x0fhostedWitnesses\x12\x1b\n\tdomain_id\x18\n \x01(\tR\x08\x64omainId\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\x87\x02\n\x0e\x43ompletionInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12%\n\x0e\x61pplication_id\x18\x02 \x01(\tR\rapplicationId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12s\n\x18opt_deduplication_period\x18\x04 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.DeduplicationPeriodR\x16optDeduplicationPeriod\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"\xe1\x03\n\x0fTransactionMeta\x12\x1f\n\x0bledger_time\x18\x01 \x01(\x03R\nledgerTime\x12=\n\x0bworkflow_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nworkflowId\x12\'\n\x0fsubmission_time\x18\x03 \x01(\x03R\x0esubmissionTime\x12\'\n\x0fsubmission_seed\x18\x04 \x01(\x0cR\x0esubmissionSeed\x12#\n\rused_packages\x18\x05 \x03(\tR\x0cusedPackages\x12Y\n\nnode_seeds\x18\x06 \x03(\x0b\x32:.com.digitalasset.canton.participant.protocol.v30.NodeSeedR\tnodeSeeds\x12n\n\x0c\x62y_key_nodes\x18\x07 \x01(\x0b\x32L.com.digitalasset.canton.participant.protocol.v30.TransactionMeta.ByKeyNodesR\nbyKeyNodes\x1a,\n\nByKeyNodes\x12\x1e\n\x0b\x62y_key_node\x18\x01 \x03(\x05R\tbyKeyNode\"F\n\x08NodeSeed\x12\x1d\n\nnode_index\x18\x01 \x01(\x05R\tnodeIndex\x12\x1b\n\tnode_seed\x18\x02 \x01(\x0cR\x08nodeSeed\"X\n\x10\x44ivulgedContract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12#\n\rcontract_inst\x18\x02 \x01(\x0cR\x0c\x63ontractInst\"\xe2\x03\n\x0c\x42lindingInfo\x12n\n\ndisclosure\x18\x01 \x03(\x0b\x32N.com.digitalasset.canton.participant.protocol.v30.BlindingInfo.DisclosureEntryR\ndisclosure\x12n\n\ndivulgence\x18\x02 \x03(\x0b\x32N.com.digitalasset.canton.participant.protocol.v30.BlindingInfo.DivulgenceEntryR\ndivulgence\x1ax\n\x0f\x44isclosureEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12O\n\x05value\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.participant.protocol.v30.PartiesR\x05value:\x02\x38\x01\x1ax\n\x0f\x44ivulgenceEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12O\n\x05value\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.participant.protocol.v30.PartiesR\x05value:\x02\x38\x01\"#\n\x07Parties\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\"\xde\x03\n\x0f\x43ommandRejected\x12i\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x1f\n\x0brecord_time\x18\x02 \x01(\x03R\nrecordTime\x12\x88\x01\n\x10rejection_reason\x18\x03 \x01(\x0b\x32].com.digitalasset.canton.participant.protocol.v30.CommandRejected.GrpcRejectionReasonTemplateR\x0frejectionReason\x12`\n\x0c\x63ommand_kind\x18\x04 \x01(\x0e\x32=.com.digitalasset.canton.participant.protocol.v30.CommandKindR\x0b\x63ommandKind\x12\x1b\n\tdomain_id\x18\x05 \x01(\tR\x08\x64omainId\x1a\x35\n\x1bGrpcRejectionReasonTemplate\x12\x16\n\x06status\x18\x01 \x01(\x0cR\x06status\"\xcd\x05\n\x0eTransferredOut\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12i\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12\x1f\n\x0b\x63ontract_id\x18\x05 \x01(\tR\ncontractId\x12\x33\n\x15\x63ontract_stakeholders\x18\x06 \x03(\tR\x14\x63ontractStakeholders\x12#\n\rsource_domain\x18\x07 \x01(\tR\x0csourceDomain\x12#\n\rtarget_domain\x18\x08 \x01(\tR\x0ctargetDomain\x12S\n\x17transfer_in_exclusivity\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15transferInExclusivity\x12\x1f\n\x0bworkflow_id\x18\n \x01(\tR\nworkflowId\x12\x1f\n\x0btemplate_id\x18\x0b \x01(\tR\ntemplateId\x12>\n\x1bis_transferring_participant\x18\x0c \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\r \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0e \x01(\x03R\x0ftransferCounter\x12!\n\x0cpackage_name\x18\x0f \x01(\tR\x0bpackageName\"\xc6\x05\n\rTransferredIn\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12i\n\x0f\x63ompletion_info\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x1c\n\tsubmitter\x18\x03 \x01(\tR\tsubmitter\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12,\n\x12ledger_create_time\x18\x05 \x01(\x03R\x10ledgerCreateTime\x12\x1f\n\x0b\x63reate_node\x18\x06 \x01(\x0cR\ncreateNode\x12\x36\n\x17\x63reating_transaction_id\x18\x07 \x01(\tR\x15\x63reatingTransactionId\x12+\n\x11\x63ontract_metadata\x18\x08 \x01(\x0cR\x10\x63ontractMetadata\x12X\n\x0ftransfer_out_id\x18\t \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v30.TransferIdR\rtransferOutId\x12#\n\rtarget_domain\x18\n \x01(\tR\x0ctargetDomain\x12\x1f\n\x0bworkflow_id\x18\x0b \x01(\tR\nworkflowId\x12>\n\x1bis_transferring_participant\x18\x0c \x01(\x08R\x19isTransferringParticipant\x12/\n\x13hosted_stakeholders\x18\r \x03(\tR\x12hostedStakeholders\x12)\n\x10transfer_counter\x18\x0e \x01(\x03R\x0ftransferCounter\"\xcb\x03\n\x0e\x43ontractsAdded\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12\x1f\n\x0bledger_time\x18\x04 \x01(\x03R\nledgerTime\x12\x1f\n\x0brecord_time\x18\x05 \x01(\x03R\nrecordTime\x12)\n\x10hosted_witnesses\x18\x06 \x03(\tR\x0fhostedWitnesses\x12\x83\x01\n\x11\x63ontract_metadata\x18\x07 \x03(\x0b\x32V.com.digitalasset.canton.participant.protocol.v30.ContractsAdded.ContractMetadataEntryR\x10\x63ontractMetadata\x12\x1f\n\x0bworkflow_id\x18\x08 \x01(\tR\nworkflowId\x1a\x43\n\x15\x43ontractMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"\xbf\x01\n\x0f\x43ontractsPurged\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x1c\n\tcontracts\x18\x02 \x03(\x0cR\tcontracts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12\x1f\n\x0brecord_time\x18\x04 \x01(\x03R\nrecordTime\x12)\n\x10hosted_witnesses\x18\x05 \x03(\tR\x0fhostedWitnesses\"\xa4\x01\n\x19PartiesAddedToParticipant\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x03 \x01(\x03R\nrecordTime\x12%\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x04 \x01(\x03R\reffectiveTime\"\xa8\x01\n\x1dPartiesRemovedFromParticipant\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x1f\n\x0brecord_time\x18\x03 \x01(\x03R\nrecordTime\x12%\n\x0e\x65\x66\x66\x65\x63tive_time\x18\x04 \x01(\x03R\reffectiveTime\"\'\n\x04Init\x12\x1f\n\x0brecord_time\x18\x01 \x01(\x03R\nrecordTime*t\n\x0b\x43ommandKind\x12(\n$COMMAND_KIND_TRANSACTION_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x43OMMAND_KIND_TRANSFER_OUT\x10\x01\x12\x1c\n\x18\x43OMMAND_KIND_TRANSFER_IN\x10\x02\x42\x61Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v30.ledger_sync_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30'
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_options = b'8\001'
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._loaded_options = None
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._loaded_options = None
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_COMMANDKIND']._serialized_start=7187
  _globals['_COMMANDKIND']._serialized_end=7303
  _globals['_LEDGERSYNCEVENT']._serialized_start=292
  _globals['_LEDGERSYNCEVENT']._serialized_end=1585
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_start=1588
  _globals['_PARTYADDEDTOPARTICIPANT']._serialized_end=1779
  _globals['_PARTYALLOCATIONREJECTED']._serialized_start=1782
  _globals['_PARTYALLOCATIONREJECTED']._serialized_end=1959
  _globals['_TRANSACTIONACCEPTED']._serialized_start=1962
  _globals['_TRANSACTIONACCEPTED']._serialized_end=2802
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_start=2735
  _globals['_TRANSACTIONACCEPTED_CONTRACTMETADATAENTRY']._serialized_end=2802
  _globals['_COMPLETIONINFO']._serialized_start=2805
  _globals['_COMPLETIONINFO']._serialized_end=3068
  _globals['_TRANSACTIONMETA']._serialized_start=3071
  _globals['_TRANSACTIONMETA']._serialized_end=3552
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_start=3508
  _globals['_TRANSACTIONMETA_BYKEYNODES']._serialized_end=3552
  _globals['_NODESEED']._serialized_start=3554
  _globals['_NODESEED']._serialized_end=3624
  _globals['_DIVULGEDCONTRACT']._serialized_start=3626
  _globals['_DIVULGEDCONTRACT']._serialized_end=3714
  _globals['_BLINDINGINFO']._serialized_start=3717
  _globals['_BLINDINGINFO']._serialized_end=4199
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_start=3957
  _globals['_BLINDINGINFO_DISCLOSUREENTRY']._serialized_end=4077
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_start=4079
  _globals['_BLINDINGINFO_DIVULGENCEENTRY']._serialized_end=4199
  _globals['_PARTIES']._serialized_start=4201
  _globals['_PARTIES']._serialized_end=4236
  _globals['_COMMANDREJECTED']._serialized_start=4239
  _globals['_COMMANDREJECTED']._serialized_end=4717
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_start=4664
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_end=4717
  _globals['_TRANSFERREDOUT']._serialized_start=4720
  _globals['_TRANSFERREDOUT']._serialized_end=5437
  _globals['_TRANSFERREDIN']._serialized_start=5440
  _globals['_TRANSFERREDIN']._serialized_end=6150
  _globals['_CONTRACTSADDED']._serialized_start=6153
  _globals['_CONTRACTSADDED']._serialized_end=6612
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_start=2735
  _globals['_CONTRACTSADDED_CONTRACTMETADATAENTRY']._serialized_end=2802
  _globals['_CONTRACTSPURGED']._serialized_start=6615
  _globals['_CONTRACTSPURGED']._serialized_end=6806
  _globals['_PARTIESADDEDTOPARTICIPANT']._serialized_start=6809
  _globals['_PARTIESADDEDTOPARTICIPANT']._serialized_end=6973
  _globals['_PARTIESREMOVEDFROMPARTICIPANT']._serialized_start=6976
  _globals['_PARTIESREMOVEDFROMPARTICIPANT']._serialized_end=7144
  _globals['_INIT']._serialized_start=7146
  _globals['_INIT']._serialized_end=7185
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .vault_service_pb2 import DeleteKeyPairRequest, DeleteKeyPairResponse, ExportKeyPairRequest, ExportKeyPairResponse, GenerateCertificateRequest, GenerateCertificateResponse, GenerateEncryptionKeyRequest, GenerateEncryptionKeyResponse, GenerateSigningKeyRequest, GenerateSigningKeyResponse, GetWrapperKeyIdRequest, GetWrapperKeyIdResponse, ImportCertificateRequest, ImportCertificateResponse, ImportKeyPairRequest, ImportKeyPairResponse, ImportPublicKeyRequest, ImportPublicKeyResponse, ListCertificateRequest, ListCertificateResponse, ListKeysFilters, ListMyKeysRequest, ListMyKeysResponse, ListPublicKeysRequest, ListPublicKeysResponse, PrivateKeyMetadata, RegisterKmsEncryptionKeyRequest, RegisterKmsEncryptionKeyResponse, RegisterKmsSigningKeyRequest, RegisterKmsSigningKeyResponse, RotateWrapperKeyRequest, RotateWrapperKeyResponse
from .vault_service_pb2_grpc import VaultServiceStub

__all__ = [
    "DeleteKeyPairRequest",
    "DeleteKeyPairResponse",
    "ExportKeyPairRequest",
    "ExportKeyPairResponse",
    "GenerateCertificateRequest",
    "GenerateCertificateResponse",
    "GenerateEncryptionKeyRequest",
    "GenerateEncryptionKeyResponse",
    "GenerateSigningKeyRequest",
    "GenerateSigningKeyResponse",
    "GetWrapperKeyIdRequest",
    "GetWrapperKeyIdResponse",
    "ImportCertificateRequest",
    "ImportCertificateResponse",
    "ImportKeyPairRequest",
    "ImportKeyPairResponse",
    "ImportPublicKeyRequest",
    "ImportPublicKeyResponse",
    "ListCertificateRequest",
    "ListCertificateResponse",
    "ListKeysFilters",
    "ListMyKeysRequest",
    "ListMyKeysResponse",
    "ListPublicKeysRequest",
    "ListPublicKeysResponse",
    "PrivateKeyMetadata",
    "RegisterKmsEncryptionKeyRequest",
    "RegisterKmsEncryptionKeyResponse",
    "RegisterKmsSigningKeyRequest",
    "RegisterKmsSigningKeyResponse",
    "RotateWrapperKeyRequest",
    "RotateWrapperKeyResponse",
    "VaultServiceStub",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from .go import go_files
from .python import python_files

__all__ = ["python_files", "go_files"]
